@@ -1,4 +1,4 @@
-/* Copyright (C) 2009-2022 Greenbone Networks GmbH
+/* Copyright (C) 2009-2022 Greenbone AG
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -199,6 +199,9 @@ extern credentials_t current_credentials;
 int
 authenticate (credentials_t*);
 
+void
+logout_user ();
+
 
 /* Database. */
 
@@ -232,6 +235,21 @@ manage_encrypt_all_credentials (GSList *, const db_conn_info_t *);
 int
 manage_decrypt_all_credentials (GSList *, const db_conn_info_t *);
 
+int
+manage_create_encryption_key (GSList *log_config,
+                              const db_conn_info_t *database);
+
+int
+manage_set_encryption_key (GSList *log_config,
+                           const db_conn_info_t *database,
+                           const char*);
+
+char *
+current_encryption_key_uid (gboolean);
+
+void
+set_current_encryption_key_uid (const char *new_uid);
+
 void
 manage_session_set_timezone (const char *);
 
@@ -373,6 +391,9 @@ trash_id_exists (const char *, const char *);
 gboolean
 find_resource (const char*, const char*, resource_t*);
 
+gboolean
+find_resource_no_acl (const char*, const char*, resource_t*);
+
 const char *
 type_name_plural (const char*);
 
@@ -1076,6 +1097,7 @@ user_has_super (const char *, user_t);
  */
 #define LSC_FAMILY_LIST                            \
   "'AIX Local Security Checks',"                   \
+  " 'AlmaLinux Local Security Checks',"            \
   " 'Amazon Linux Local Security Checks',"         \
   " 'CentOS Local Security Checks',"               \
   " 'Citrix Xenserver Local Security Checks',"     \
@@ -1094,6 +1116,7 @@ user_has_super (const char *, user_t);
   " 'Oracle Linux Local Security Checks',"         \
   " 'Palo Alto PAN-OS Local Security Checks',"     \
   " 'Red Hat Local Security Checks',"              \
+  " 'Rocky Linux Local Security Checks',"          \
   " 'Slackware Local Security Checks',"            \
   " 'Solaris Local Security Checks',"              \
   " 'SuSE Local Security Checks',"                 \
@@ -1105,12 +1128,23 @@ user_has_super (const char *, user_t);
  * @brief Whole only families.
  */
 #define FAMILIES_WHOLE_ONLY                        \
-  { "CentOS Local Security Checks",                \
+  { "AIX Local Security Checks",                   \
+    "AlmaLinux Local Security Checks",             \
+    "Amazon Linux Local Security Checks",          \
+    "CentOS Local Security Checks",                \
     "Debian Local Security Checks",                \
     "Fedora Local Security Checks",                \
+    "FreeBSD Local Security Checks",               \
+    "Gentoo Local Security Checks",                \
+    "HP-UX Local Security Checks",                 \
     "Huawei EulerOS Local Security Checks",        \
+    "Mageia Linux Local Security Checks",          \
+    "Mandrake Local Security Checks",              \
     "Oracle Linux Local Security Checks",          \
     "Red Hat Local Security Checks",               \
+    "Rocky Linux Local Security Checks",           \
+    "Slackware Local Security Checks",             \
+    "Solaris Local Security Checks",               \
     "SuSE Local Security Checks",                  \
     "Ubuntu Local Security Checks",                \
     NULL }
@@ -1146,6 +1180,13 @@ result_detection_reference (result_t, report_t, const char *, const char *,
  */
 #define MIN_QOD_DEFAULT 70
 
+/** 
+ * @brief Default size to limit note and override text to in reports.
+ */
+#define EXCERPT_SIZE_DEFAULT 300
+
+
+
 void
 reports_clear_count_cache_for_override (override_t, int);
 
@@ -1180,7 +1221,8 @@ make_result (task_t, const char*, const char*, const char*, const char*,
 
 result_t
 make_osp_result (task_t, const char*, const char*, const char*, const char*,
-                 const char *, const char *, const char *, int, const char*);
+                 const char *, const char *, const char *, int, const char*,
+                 const char *);
 
 result_t
 make_cve_result (task_t, const char*, const char*, double, const char*);
@@ -1232,7 +1274,8 @@ host_detail_free (host_detail_t *);
 
 void
 insert_report_host_detail (report_t, const char *, const char *, const char *,
-                           const char *, const char *, const char *);
+                           const char *, const char *, const char *,
+                           const char *);
 
 int
 manage_report_host_detail (report_t, const char *, const char *);
@@ -1917,7 +1960,8 @@ nvt_selector_iterator_type (iterator_t*);
 /* NVT preferences. */
 
 void
-manage_nvt_preference_add (const char*, const char*);
+manage_nvt_preference_add (const char*, const char*, const char*, const char*,
+                           const char*, const char*, int);
 
 void
 manage_nvt_preferences_enable ();
@@ -1953,7 +1997,7 @@ void
 xml_append_nvt_refs (GString *, const char *, int *);
 
 gchar*
-get_nvt_xml (iterator_t*, int, int, int, const char*, config_t, int);
+get_nvt_xml (iterator_t*, int, int, int, const char*, config_t, int, int);
 
 char*
 task_preference_value (task_t, const char *);
@@ -2237,6 +2281,9 @@ asset_os_iterator_highest_severity (iterator_t *);
 const char*
 asset_os_iterator_average_severity (iterator_t *);
 
+int
+asset_os_iterator_all_installs (iterator_t *);
+
 int
 asset_os_count (const get_data_t *);
 
@@ -3158,6 +3205,9 @@ cpe_info_iterator_cve_refs (iterator_t*);
 const char*
 cpe_info_iterator_nvd_id (iterator_t*);
 
+gchar *
+cpe_details_xml (const char*);
+
 /* CVE. */
 
 const char*
@@ -3269,6 +3319,9 @@ setting_is_default_ca_cert (const gchar *);
 char *
 setting_filter (const char *);
 
+int
+setting_excerpt_size_int ();
+
 void
 init_setting_iterator (iterator_t *, const char *, const char *, int, int, int,
                        const char *);
@@ -3451,10 +3504,16 @@ int
 vuln_count (const get_data_t*);
 
 void
-manage_get_ldap_info (int *, gchar **, gchar **, int *, gchar **);
+manage_get_ldap_info (int *, gchar **, gchar **, int *, gchar **, int *);
 
 void
-manage_set_ldap_info (int, gchar *, gchar *, int, gchar *);
+manage_set_ldap_info (int, gchar *, gchar *, int, gchar *, int);
+
+char *
+get_radius_key (gboolean *);
+
+void
+set_radius_key (const char*, gboolean);
 
 void
 manage_get_radius_info (int *, char **, char **);
@@ -3614,6 +3673,12 @@ manage_gvmd_data_feed_dir_exists (const char *);
 gboolean
 manage_gvmd_data_feed_dirs_exist ();
 
+int
+get_auth_timeout ();
+
+void
+set_auth_timeout (int);
+
 const gchar *
 get_broker_address ();
 
