@@ -1,4 +1,4 @@
-/* Copyright (C) 2013-2022 Greenbone Networks GmbH
+/* Copyright (C) 2013-2022 Greenbone AG
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -2942,6 +2942,240 @@ migrate_249_to_250 ()
   return 0;
 }
 
+/**
+ * @brief Migrate the database from version 250 to version 251.
+ *
+ * @return 0 success, -1 error.
+ */
+int
+migrate_250_to_251 ()
+{
+  sql_begin_immediate ();
+
+  /* Ensure that the database is currently version 249. */
+
+  if (manage_db_version () != 250)
+    {
+      sql_rollback ();
+      return -1;
+    }
+
+  /* Update the database. */
+
+  char *secret_key = NULL;
+
+  secret_key = sql_string ("SELECT value FROM meta WHERE name = 'radius_key';");
+
+  if (secret_key)
+    {
+      char *secret;
+      char *quoted;
+      lsc_crypt_ctx_t crypt_ctx;
+      crypt_ctx = lsc_crypt_new (OLD_ENCRYPTION_KEY_UID);
+
+      sql ("DELETE FROM meta WHERE name LIKE 'radius_key';");
+      secret = lsc_crypt_encrypt (crypt_ctx, "secret_key", secret_key, NULL);
+      if (secret)
+        {
+          quoted = sql_quote (secret);
+          sql ("INSERT INTO meta (name, value) VALUES ('radius_key', '%s');", quoted);
+          g_free (secret);
+          secret = NULL;
+          g_free (quoted);
+        }
+      lsc_crypt_release(crypt_ctx);
+      g_free (secret_key);
+    }
+
+  /* Set the database version to 251. */
+
+  set_db_version (251);
+
+  sql_commit ();
+
+  return 0;
+}
+
+/**
+ * @brief Migrate the database from version 251 to version 252.
+ *
+ * @return 0 success, -1 error.
+ */
+int
+migrate_251_to_252 ()
+{
+  sql_begin_immediate ();
+
+  /* Ensure that the database is currently version 251. */
+
+  if (manage_db_version () != 251)
+    {
+      sql_rollback ();
+      return -1;
+    }
+
+  /* Update the database. */
+
+  sql ("ALTER TABLE IF EXISTS results ADD COLUMN hash_value text;");
+
+  /* Set the database version to 252. */
+
+  set_db_version (252);
+
+  sql_commit ();
+
+  return 0;
+}
+
+/**
+ * @brief Migrate the database from version 252 to version 253.
+ *
+ * @return 0 success, -1 error.
+ */
+int
+migrate_252_to_253 ()
+{
+  sql_begin_immediate ();
+
+  /* Ensure that the database is currently version 252. */
+
+  if (manage_db_version () != 252)
+    {
+      sql_rollback ();
+      return -1;
+    }
+
+  /* Update the database. */
+
+  sql ("ALTER TABLE IF EXISTS report_host_details ADD COLUMN hash_value text;");
+
+  /* Set the database version to 253. */
+
+  set_db_version (253);
+
+  sql_commit ();
+
+  return 0;
+}
+
+/**
+ * @brief Alter and update for migrate_253_to_254.
+ *
+ * @param[in]  trash  Whether to alter trash tables.
+ */
+static void
+migrate_253_to_254_alter (int trash)
+{
+  sql ("ALTER TABLE config_preferences%s ADD COLUMN pref_nvt text;",
+       trash ? "_trash" : "");
+  sql ("UPDATE config_preferences%s"
+       " SET pref_nvt = substring (name, '^([^:]*)')"
+       " WHERE name ~ '^[^:]*:[0-9]+:[^:]*:.*';",
+       trash ? "_trash" : "");
+
+  sql ("ALTER TABLE config_preferences%s ADD COLUMN pref_id integer;",
+       trash ? "_trash" : "");
+  sql ("UPDATE config_preferences%s"
+       " SET pref_id = CAST (substring (name, '^[^:]*:([0-9]+)') AS integer)"
+       " WHERE name ~ '^[^:]*:[0-9]+:[^:]*:.*';",
+       trash ? "_trash" : "");
+
+  sql ("ALTER table config_preferences%s ADD COLUMN pref_type text;",
+       trash ? "_trash" : "");
+  sql ("UPDATE config_preferences%s"
+       " SET pref_type = substring (name, '^[^:]*:[0-9]+:([^:]*):')"
+       " WHERE name ~ '^[^:]*:[0-9]+:[^:]*:.*';",
+       trash ? "_trash" : "");
+
+  sql ("ALTER table config_preferences%s ADD COLUMN pref_name text;",
+       trash ? "_trash" : "");
+  sql ("UPDATE config_preferences%s"
+       " SET pref_name = substring (name, '^[^:]*:[0-9]+:[^:]*:(.*)')"
+       " WHERE name ~ '^[^:]*:[0-9]+:[^:]*:.*';",
+       trash ? "_trash" : "");
+}
+
+/**
+ * @brief Migrate the database from version 253 to version 254.
+ *
+ * @return 0 success, -1 error.
+ */
+int
+migrate_253_to_254 ()
+{
+  sql_begin_immediate ();
+
+  /* Ensure that the database is currently version 253. */
+
+  if (manage_db_version () != 253)
+    {
+      sql_rollback ();
+      return -1;
+    }
+
+  /* Update the database. */
+
+  migrate_253_to_254_alter(0);
+  migrate_253_to_254_alter(1);
+
+  /* Set the database version to 254. */
+
+  set_db_version (254);
+
+  sql_commit ();
+
+  return 0;
+}
+
+/**
+ * @brief Migrate the database from version 254 to version 255.
+ *
+ * @return 0 success, -1 error.
+ */
+int
+migrate_254_to_255 ()
+{
+  sql_begin_immediate ();
+
+  /* Ensure that the database is currently version 254. */
+
+  if (manage_db_version () != 254)
+    {
+      sql_rollback ();
+      return -1;
+    }
+
+  /* Update the database. */
+
+  sql ("ALTER TABLE nvt_preferences ADD COLUMN pref_nvt text;");
+  sql ("UPDATE nvt_preferences"
+       " SET pref_nvt = substring (name, '^([^:]*)')"
+       " WHERE name ~ '^[^:]*:[0-9]+:[^:]*:.*';");
+
+  sql ("ALTER TABLE nvt_preferences ADD COLUMN pref_id integer;");
+  sql ("UPDATE nvt_preferences"
+       " SET pref_id = CAST (substring (name, '^[^:]*:([0-9]+)') AS integer)"
+       " WHERE name ~ '^[^:]*:[0-9]+:[^:]*:.*';");
+
+  sql ("ALTER table nvt_preferences ADD COLUMN pref_type text;");
+  sql ("UPDATE nvt_preferences"
+       " SET pref_type = substring (name, '^[^:]*:[0-9]+:([^:]*):')"
+       " WHERE name ~ '^[^:]*:[0-9]+:[^:]*:.*';");
+
+  sql ("ALTER table nvt_preferences ADD COLUMN pref_name text;");
+  sql ("UPDATE nvt_preferences"
+       " SET pref_name = substring (name, '^[^:]*:[0-9]+:[^:]*:(.*)')"
+       " WHERE name ~ '^[^:]*:[0-9]+:[^:]*:.*';");
+
+  /* Set the database version to 255. */
+
+  set_db_version (255);
+
+  sql_commit ();
+
+  return 0;
+}
+
 #undef UPDATE_DASHBOARD_SETTINGS
 
 /**
@@ -2998,6 +3232,11 @@ static migrator_t database_migrators[] = {
   {248, migrate_247_to_248},
   {249, migrate_248_to_249},
   {250, migrate_249_to_250},
+  {251, migrate_250_to_251},
+  {252, migrate_251_to_252},
+  {253, migrate_252_to_253},
+  {254, migrate_253_to_254},
+  {255, migrate_254_to_255},
   /* End marker. */
   {-1, NULL}};
 
