@@ -1,4 +1,4 @@
-/* Copyright (C) 2010-2022 Greenbone Networks GmbH
+/* Copyright (C) 2010-2022 Greenbone AG
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
  *
@@ -112,6 +112,11 @@
  */
 #define SETTING_UUID_MAX_ROWS_PER_PAGE "76374a7a-0569-11e6-b6da-28d24461215b"
 
+/**
+ * @brief UUID of 'Note/Override Excerpt Size' setting.
+ */
+#define SETTING_UUID_EXCERPT_SIZE "9246a0f6-c6ad-44bc-86c2-557a527c8fb3"
+
 /**
  * @brief UUID of 'Default CA Cert' setting.
  */
@@ -295,6 +300,12 @@ host_nthlast_report_host (const char *, report_host_t *, int);
 char*
 report_host_ip (const char *);
 
+gchar *report_host_hostname (report_host_t);
+
+gchar *report_host_best_os_cpe (report_host_t);
+
+gchar *report_host_best_os_txt (report_host_t);
+
 void trim_report (report_t);
 
 int delete_report_internal (report_t);
